from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from libica.openapi.libconsole.api.accounts_api import AccountsApi
from libica.openapi.libconsole.api.health_api import HealthApi
from libica.openapi.libconsole.api.projects_api import ProjectsApi
from libica.openapi.libconsole.api.tokens_api import TokensApi
from libica.openapi.libconsole.api.workgroups_api import WorkgroupsApi



# coding: utf-8

# flake8: noqa
"""
    Developer Console Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from libica.openapi.libconsole.models.access_token_request import AccessTokenRequest
from libica.openapi.libconsole.models.account_response import AccountResponse
from libica.openapi.libconsole.models.domain import Domain
from libica.openapi.libconsole.models.error_response import ErrorResponse
from libica.openapi.libconsole.models.health_check_statuses import HealthCheckStatuses
from libica.openapi.libconsole.models.project import Project
from libica.openapi.libconsole.models.project_paged_items import ProjectPagedItems
from libica.openapi.libconsole.models.service_health_response import ServiceHealthResponse
from libica.openapi.libconsole.models.system_health_response import SystemHealthResponse
from libica.openapi.libconsole.models.token_detail_response import TokenDetailResponse
from libica.openapi.libconsole.models.token_response import TokenResponse
from libica.openapi.libconsole.models.workgroup import Workgroup
from libica.openapi.libconsole.models.workgroup_response import WorkgroupResponse



# coding: utf-8

"""
    Task Execution Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from libica.openapi.libtes.configuration import Configuration


class HeartbeatTaskRunRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'last_heartbeat': 'bool',
        'pod_name': 'str',
        'pod_uid': 'str',
        'pod_hardware_details': 'str',
        'job_retry_count': 'int',
        'nonce': 'str',
        'container_status': 'list[ContainerStatus]'
    }

    attribute_map = {
        'last_heartbeat': 'lastHeartbeat',
        'pod_name': 'podName',
        'pod_uid': 'podUID',
        'pod_hardware_details': 'podHardwareDetails',
        'job_retry_count': 'jobRetryCount',
        'nonce': 'nonce',
        'container_status': 'containerStatus'
    }

    def __init__(self, last_heartbeat=None, pod_name=None, pod_uid=None, pod_hardware_details=None, job_retry_count=None, nonce=None, container_status=None, local_vars_configuration=None):  # noqa: E501
        """HeartbeatTaskRunRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._last_heartbeat = None
        self._pod_name = None
        self._pod_uid = None
        self._pod_hardware_details = None
        self._job_retry_count = None
        self._nonce = None
        self._container_status = None
        self.discriminator = None

        if last_heartbeat is not None:
            self.last_heartbeat = last_heartbeat
        if pod_name is not None:
            self.pod_name = pod_name
        if pod_uid is not None:
            self.pod_uid = pod_uid
        if pod_hardware_details is not None:
            self.pod_hardware_details = pod_hardware_details
        if job_retry_count is not None:
            self.job_retry_count = job_retry_count
        if nonce is not None:
            self.nonce = nonce
        if container_status is not None:
            self.container_status = container_status

    @property
    def last_heartbeat(self):
        """Gets the last_heartbeat of this HeartbeatTaskRunRequest.  # noqa: E501

        LastHeartbeat  # noqa: E501

        :return: The last_heartbeat of this HeartbeatTaskRunRequest.  # noqa: E501
        :rtype: bool
        """
        return self._last_heartbeat

    @last_heartbeat.setter
    def last_heartbeat(self, last_heartbeat):
        """Sets the last_heartbeat of this HeartbeatTaskRunRequest.

        LastHeartbeat  # noqa: E501

        :param last_heartbeat: The last_heartbeat of this HeartbeatTaskRunRequest.  # noqa: E501
        :type: bool
        """

        self._last_heartbeat = last_heartbeat

    @property
    def pod_name(self):
        """Gets the pod_name of this HeartbeatTaskRunRequest.  # noqa: E501


        :return: The pod_name of this HeartbeatTaskRunRequest.  # noqa: E501
        :rtype: str
        """
        return self._pod_name

    @pod_name.setter
    def pod_name(self, pod_name):
        """Sets the pod_name of this HeartbeatTaskRunRequest.


        :param pod_name: The pod_name of this HeartbeatTaskRunRequest.  # noqa: E501
        :type: str
        """

        self._pod_name = pod_name

    @property
    def pod_uid(self):
        """Gets the pod_uid of this HeartbeatTaskRunRequest.  # noqa: E501


        :return: The pod_uid of this HeartbeatTaskRunRequest.  # noqa: E501
        :rtype: str
        """
        return self._pod_uid

    @pod_uid.setter
    def pod_uid(self, pod_uid):
        """Sets the pod_uid of this HeartbeatTaskRunRequest.


        :param pod_uid: The pod_uid of this HeartbeatTaskRunRequest.  # noqa: E501
        :type: str
        """

        self._pod_uid = pod_uid

    @property
    def pod_hardware_details(self):
        """Gets the pod_hardware_details of this HeartbeatTaskRunRequest.  # noqa: E501


        :return: The pod_hardware_details of this HeartbeatTaskRunRequest.  # noqa: E501
        :rtype: str
        """
        return self._pod_hardware_details

    @pod_hardware_details.setter
    def pod_hardware_details(self, pod_hardware_details):
        """Sets the pod_hardware_details of this HeartbeatTaskRunRequest.


        :param pod_hardware_details: The pod_hardware_details of this HeartbeatTaskRunRequest.  # noqa: E501
        :type: str
        """

        self._pod_hardware_details = pod_hardware_details

    @property
    def job_retry_count(self):
        """Gets the job_retry_count of this HeartbeatTaskRunRequest.  # noqa: E501


        :return: The job_retry_count of this HeartbeatTaskRunRequest.  # noqa: E501
        :rtype: int
        """
        return self._job_retry_count

    @job_retry_count.setter
    def job_retry_count(self, job_retry_count):
        """Sets the job_retry_count of this HeartbeatTaskRunRequest.


        :param job_retry_count: The job_retry_count of this HeartbeatTaskRunRequest.  # noqa: E501
        :type: int
        """

        self._job_retry_count = job_retry_count

    @property
    def nonce(self):
        """Gets the nonce of this HeartbeatTaskRunRequest.  # noqa: E501


        :return: The nonce of this HeartbeatTaskRunRequest.  # noqa: E501
        :rtype: str
        """
        return self._nonce

    @nonce.setter
    def nonce(self, nonce):
        """Sets the nonce of this HeartbeatTaskRunRequest.


        :param nonce: The nonce of this HeartbeatTaskRunRequest.  # noqa: E501
        :type: str
        """

        self._nonce = nonce

    @property
    def container_status(self):
        """Gets the container_status of this HeartbeatTaskRunRequest.  # noqa: E501


        :return: The container_status of this HeartbeatTaskRunRequest.  # noqa: E501
        :rtype: list[ContainerStatus]
        """
        return self._container_status

    @container_status.setter
    def container_status(self, container_status):
        """Sets the container_status of this HeartbeatTaskRunRequest.


        :param container_status: The container_status of this HeartbeatTaskRunRequest.  # noqa: E501
        :type: list[ContainerStatus]
        """

        self._container_status = container_status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HeartbeatTaskRunRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, HeartbeatTaskRunRequest):
            return True

        return self.to_dict() != other.to_dict()



"""
    ICA Rest API

    This API can be used to interact with Illumina Connected Analytics.<br> <h2>Authentication</h2> <p> Authentication to the  API can be done in multiple ways:<br> <ul><li>For the entire API, except for the POST /tokens endpoint: API-key + JWT</li> <li>Only for the POST /tokens endpoint: API-key + Basic Authentication</li></ul> </p> <p> <h4>API-key</h4> API keys are managed within the Illumina portal where you can manage your profile after you have logged on. The API-key has to be provided in the X-API-Key header parameter when executing API calls to ICA. In the background, a JWT will be requested at the IDP of Illumina to create a session. A good practice is to not use the API-key for every API call, but to first generate a JWT and to use that for authentication in subsequent calls.<br> </p> <p> <h4>JWT</h4> To avoid using an API-key for each call, we recommend to request a JWT via the POST /tokens endpoint  using this API-key. The JWT will expire after a pre-configured period specified by a tenant administrator through the IAM console in the Illumina portal. The JWT is the preferred way for authentication.<br>A not yet expired, still valid JWT could be refreshed using the POST /tokens:refresh endpoint.<br>Refreshing the JWT is not possible if the JWT was generated by using an API-key.<br> </p> <p> <h4>Basic Authentication</h4> Basic authentication is only supported by the POST /tokens endpoint for generating a JWT. Use \"Basic base64encoded(emailaddress:password)\" in the \"Authorization\" header parameter for this authentication method. In case having access to multiple tenants using the same email-address, also provide the \"tenant\" request parameter to indicate what tenant you would like to request a JWT for. </p> <p> <h2>Compression</h2> If the API client provides request header 'Accept-Encoding' with value 'gzip', then the API applies GZIP compression on the JSON response. This significantly reduces the size and thus the download time of the response, which results in faster end-to-end API calls. In case of compression, the API also provides response header 'Content-Encoding' with value 'gzip', as indication for the client that decompression is required. </p>   # noqa: E501

    The version of the OpenAPI document: 3
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from libica.openapi.v2.api_client import ApiClient, Endpoint as _Endpoint
from libica.openapi.v2.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from libica.openapi.v2.model.analysis_paged_list import AnalysisPagedList
from libica.openapi.v2.model.create_sample import CreateSample
from libica.openapi.v2.model.data_list import DataList
from libica.openapi.v2.model.field import Field
from libica.openapi.v2.model.find_project_samples import FindProjectSamples
from libica.openapi.v2.model.problem import Problem
from libica.openapi.v2.model.project_list import ProjectList
from libica.openapi.v2.model.project_sample import ProjectSample
from libica.openapi.v2.model.project_sample_paged_list import ProjectSamplePagedList
from libica.openapi.v2.model.sample import Sample
from libica.openapi.v2.model.sample_history_list import SampleHistoryList
from libica.openapi.v2.model.update_metadata import UpdateMetadata


class ProjectSampleApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.add_metadata_model_to_sample_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [
                    'ApiKeyAuth',
                    'JwtAuth'
                ],
                'endpoint_path': '/api/projects/{projectId}/samples/{sampleId}/metadata/{metadataModelId}',
                'operation_id': 'add_metadata_model_to_sample',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'project_id',
                    'sample_id',
                    'metadata_model_id',
                ],
                'required': [
                    'project_id',
                    'sample_id',
                    'metadata_model_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'project_id':
                        (str,),
                    'sample_id':
                        (str,),
                    'metadata_model_id':
                        (str,),
                },
                'attribute_map': {
                    'project_id': 'projectId',
                    'sample_id': 'sampleId',
                    'metadata_model_id': 'metadataModelId',
                },
                'location_map': {
                    'project_id': 'path',
                    'sample_id': 'path',
                    'metadata_model_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/problem+json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.complete_project_sample_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [
                    'ApiKeyAuth',
                    'JwtAuth'
                ],
                'endpoint_path': '/api/projects/{projectId}/samples/{sampleId}:complete',
                'operation_id': 'complete_project_sample',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'project_id',
                    'sample_id',
                ],
                'required': [
                    'project_id',
                    'sample_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'project_id':
                        (str,),
                    'sample_id':
                        (str,),
                },
                'attribute_map': {
                    'project_id': 'projectId',
                    'sample_id': 'sampleId',
                },
                'location_map': {
                    'project_id': 'path',
                    'sample_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/problem+json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.create_sample_in_project_endpoint = _Endpoint(
            settings={
                'response_type': (ProjectSample,),
                'auth': [
                    'ApiKeyAuth',
                    'JwtAuth'
                ],
                'endpoint_path': '/api/projects/{projectId}/samples',
                'operation_id': 'create_sample_in_project',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'project_id',
                    'create_sample',
                ],
                'required': [
                    'project_id',
                    'create_sample',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'project_id':
                        (str,),
                    'create_sample':
                        (CreateSample,),
                },
                'attribute_map': {
                    'project_id': 'projectId',
                },
                'location_map': {
                    'project_id': 'path',
                    'create_sample': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/problem+json',
                    'application/vnd.illumina.v3+json'
                ],
                'content_type': [
                    'application/vnd.illumina.v3+json',
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.deep_delete_sample_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [
                    'ApiKeyAuth',
                    'JwtAuth'
                ],
                'endpoint_path': '/api/projects/{projectId}/samples/{sampleId}:deleteDeep',
                'operation_id': 'deep_delete_sample',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'project_id',
                    'sample_id',
                ],
                'required': [
                    'project_id',
                    'sample_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'project_id':
                        (str,),
                    'sample_id':
                        (str,),
                },
                'attribute_map': {
                    'project_id': 'projectId',
                    'sample_id': 'sampleId',
                },
                'location_map': {
                    'project_id': 'path',
                    'sample_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/problem+json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.delete_and_unlink_sample_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [
                    'ApiKeyAuth',
                    'JwtAuth'
                ],
                'endpoint_path': '/api/projects/{projectId}/samples/{sampleId}:deleteUnlink',
                'operation_id': 'delete_and_unlink_sample',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'project_id',
                    'sample_id',
                ],
                'required': [
                    'project_id',
                    'sample_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'project_id':
                        (str,),
                    'sample_id':
                        (str,),
                },
                'attribute_map': {
                    'project_id': 'projectId',
                    'sample_id': 'sampleId',
                },
                'location_map': {
                    'project_id': 'path',
                    'sample_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/problem+json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.delete_sample_with_input_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [
                    'ApiKeyAuth',
                    'JwtAuth'
                ],
                'endpoint_path': '/api/projects/{projectId}/samples/{sampleId}:deleteWithInput',
                'operation_id': 'delete_sample_with_input',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'project_id',
                    'sample_id',
                ],
                'required': [
                    'project_id',
                    'sample_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'project_id':
                        (str,),
                    'sample_id':
                        (str,),
                },
                'attribute_map': {
                    'project_id': 'projectId',
                    'sample_id': 'sampleId',
                },
                'location_map': {
                    'project_id': 'path',
                    'sample_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/problem+json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_project_sample_endpoint = _Endpoint(
            settings={
                'response_type': (ProjectSample,),
                'auth': [
                    'ApiKeyAuth',
                    'JwtAuth'
                ],
                'endpoint_path': '/api/projects/{projectId}/samples/{sampleId}',
                'operation_id': 'get_project_sample',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'project_id',
                    'sample_id',
                ],
                'required': [
                    'project_id',
                    'sample_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'project_id':
                        (str,),
                    'sample_id':
                        (str,),
                },
                'attribute_map': {
                    'project_id': 'projectId',
                    'sample_id': 'sampleId',
                },
                'location_map': {
                    'project_id': 'path',
                    'sample_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/problem+json',
                    'application/vnd.illumina.v3+json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_project_sample_analyses_endpoint = _Endpoint(
            settings={
                'response_type': (AnalysisPagedList,),
                'auth': [
                    'ApiKeyAuth',
                    'JwtAuth'
                ],
                'endpoint_path': '/api/projects/{projectId}/samples/{sampleId}/analyses',
                'operation_id': 'get_project_sample_analyses',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'project_id',
                    'sample_id',
                    'reference',
                    'userreference',
                    'status',
                    'usertag',
                    'technicaltag',
                    'referencetag',
                    'page_offset',
                    'page_token',
                    'page_size',
                    'sort',
                ],
                'required': [
                    'project_id',
                    'sample_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'project_id':
                        (str,),
                    'sample_id':
                        (str,),
                    'reference':
                        (str,),
                    'userreference':
                        (str,),
                    'status':
                        (str,),
                    'usertag':
                        (str,),
                    'technicaltag':
                        (str,),
                    'referencetag':
                        (str,),
                    'page_offset':
                        (str,),
                    'page_token':
                        (str,),
                    'page_size':
                        (str,),
                    'sort':
                        (str,),
                },
                'attribute_map': {
                    'project_id': 'projectId',
                    'sample_id': 'sampleId',
                    'reference': 'reference',
                    'userreference': 'userreference',
                    'status': 'status',
                    'usertag': 'usertag',
                    'technicaltag': 'technicaltag',
                    'referencetag': 'referencetag',
                    'page_offset': 'pageOffset',
                    'page_token': 'pageToken',
                    'page_size': 'pageSize',
                    'sort': 'sort',
                },
                'location_map': {
                    'project_id': 'path',
                    'sample_id': 'path',
                    'reference': 'query',
                    'userreference': 'query',
                    'status': 'query',
                    'usertag': 'query',
                    'technicaltag': 'query',
                    'referencetag': 'query',
                    'page_offset': 'query',
                    'page_token': 'query',
                    'page_size': 'query',
                    'sort': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/problem+json',
                    'application/vnd.illumina.v3+json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_project_samples_endpoint = _Endpoint(
            settings={
                'response_type': (ProjectSamplePagedList,),
                'auth': [
                    'ApiKeyAuth',
                    'JwtAuth'
                ],
                'endpoint_path': '/api/projects/{projectId}/samples:search',
                'operation_id': 'get_project_samples',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'project_id',
                    'find_project_samples',
                    'page_offset',
                    'page_token',
                    'page_size',
                    'sort',
                ],
                'required': [
                    'project_id',
                    'find_project_samples',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'project_id':
                        (str,),
                    'find_project_samples':
                        (FindProjectSamples,),
                    'page_offset':
                        (str,),
                    'page_token':
                        (str,),
                    'page_size':
                        (str,),
                    'sort':
                        (str,),
                },
                'attribute_map': {
                    'project_id': 'projectId',
                    'page_offset': 'pageOffset',
                    'page_token': 'pageToken',
                    'page_size': 'pageSize',
                    'sort': 'sort',
                },
                'location_map': {
                    'project_id': 'path',
                    'find_project_samples': 'body',
                    'page_offset': 'query',
                    'page_token': 'query',
                    'page_size': 'query',
                    'sort': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/problem+json',
                    'application/vnd.illumina.v3+json'
                ],
                'content_type': [
                    'application/vnd.illumina.v3+json',
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.get_projects_for_sample_endpoint = _Endpoint(
            settings={
                'response_type': (ProjectList,),
                'auth': [
                    'ApiKeyAuth',
                    'JwtAuth'
                ],
                'endpoint_path': '/api/projects/{projectId}/samples/{sampleId}/projects',
                'operation_id': 'get_projects_for_sample',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'project_id',
                    'sample_id',
                ],
                'required': [
                    'project_id',
                    'sample_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'project_id':
                        (str,),
                    'sample_id':
                        (str,),
                },
                'attribute_map': {
                    'project_id': 'projectId',
                    'sample_id': 'sampleId',
                },
                'location_map': {
                    'project_id': 'path',
                    'sample_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/problem+json',
                    'application/vnd.illumina.v3+json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_sample_data_list_endpoint = _Endpoint(
            settings={
                'response_type': (DataList,),
                'auth': [
                    'ApiKeyAuth',
                    'JwtAuth'
                ],
                'endpoint_path': '/api/projects/{projectId}/samples/{sampleId}/data',
                'operation_id': 'get_sample_data_list',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'project_id',
                    'sample_id',
                    'full_text',
                    'id',
                    'filename',
                    'filename_match_mode',
                    'file_path',
                    'file_path_match_mode',
                    'status',
                    'format_id',
                    'format_code',
                    'type',
                    'parent_folder_id',
                    'parent_folder_path',
                    'creation_date_after',
                    'creation_date_before',
                    'status_date_after',
                    'status_date_before',
                    'user_tag',
                    'user_tag_match_mode',
                    'run_input_tag',
                    'run_input_tag_match_mode',
                    'run_output_tag',
                    'run_output_tag_match_mode',
                    'connector_tag',
                    'connector_tag_match_mode',
                    'technical_tag',
                    'technical_tag_match_mode',
                    'not_in_run',
                    'instrument_run_id',
                    'page_offset',
                    'page_token',
                    'page_size',
                    'sort',
                ],
                'required': [
                    'project_id',
                    'sample_id',
                ],
                'nullable': [
                ],
                'enum': [
                    'filename_match_mode',
                    'file_path_match_mode',
                    'status',
                    'type',
                    'user_tag_match_mode',
                    'run_input_tag_match_mode',
                    'run_output_tag_match_mode',
                    'connector_tag_match_mode',
                    'technical_tag_match_mode',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('filename_match_mode',): {

                        "EXACT": "EXACT",
                        "EXCLUDE": "EXCLUDE",
                        "FUZZY": "FUZZY"
                    },
                    ('file_path_match_mode',): {

                        "STARTS_WITH_CASE_INSENSITIVE": "STARTS_WITH_CASE_INSENSITIVE",
                        "FULL_CASE_INSENSITIVE": "FULL_CASE_INSENSITIVE"
                    },
                    ('status',): {

                        "PARTIAL": "PARTIAL",
                        "AVAILABLE": "AVAILABLE",
                        "ARCHIVING": "ARCHIVING",
                        "ARCHIVED": "ARCHIVED",
                        "UNARCHIVING": "UNARCHIVING",
                        "DELETING": "DELETING"
                    },
                    ('type',): {

                        "FILE": "FILE",
                        "FOLDER": "FOLDER"
                    },
                    ('user_tag_match_mode',): {

                        "EXACT": "EXACT",
                        "EXCLUDE": "EXCLUDE",
                        "FUZZY": "FUZZY"
                    },
                    ('run_input_tag_match_mode',): {

                        "EXACT": "EXACT",
                        "EXCLUDE": "EXCLUDE",
                        "FUZZY": "FUZZY"
                    },
                    ('run_output_tag_match_mode',): {

                        "EXACT": "EXACT",
                        "EXCLUDE": "EXCLUDE",
                        "FUZZY": "FUZZY"
                    },
                    ('connector_tag_match_mode',): {

                        "EXACT": "EXACT",
                        "EXCLUDE": "EXCLUDE",
                        "FUZZY": "FUZZY"
                    },
                    ('technical_tag_match_mode',): {

                        "EXACT": "EXACT",
                        "EXCLUDE": "EXCLUDE",
                        "FUZZY": "FUZZY"
                    },
                },
                'openapi_types': {
                    'project_id':
                        (str,),
                    'sample_id':
                        (str,),
                    'full_text':
                        (str,),
                    'id':
                        ([str],),
                    'filename':
                        ([str],),
                    'filename_match_mode':
                        (str,),
                    'file_path':
                        ([str],),
                    'file_path_match_mode':
                        (str,),
                    'status':
                        ([str],),
                    'format_id':
                        ([str],),
                    'format_code':
                        ([str],),
                    'type':
                        (str,),
                    'parent_folder_id':
                        ([str],),
                    'parent_folder_path':
                        (str,),
                    'creation_date_after':
                        (datetime,),
                    'creation_date_before':
                        (datetime,),
                    'status_date_after':
                        (datetime,),
                    'status_date_before':
                        (datetime,),
                    'user_tag':
                        ([str],),
                    'user_tag_match_mode':
                        (str,),
                    'run_input_tag':
                        ([str],),
                    'run_input_tag_match_mode':
                        (str,),
                    'run_output_tag':
                        ([str],),
                    'run_output_tag_match_mode':
                        (str,),
                    'connector_tag':
                        ([str],),
                    'connector_tag_match_mode':
                        (str,),
                    'technical_tag':
                        ([str],),
                    'technical_tag_match_mode':
                        (str,),
                    'not_in_run':
                        (bool,),
                    'instrument_run_id':
                        ([str],),
                    'page_offset':
                        (str,),
                    'page_token':
                        (str,),
                    'page_size':
                        (str,),
                    'sort':
                        (str,),
                },
                'attribute_map': {
                    'project_id': 'projectId',
                    'sample_id': 'sampleId',
                    'full_text': 'fullText',
                    'id': 'id',
                    'filename': 'filename',
                    'filename_match_mode': 'filenameMatchMode',
                    'file_path': 'filePath',
                    'file_path_match_mode': 'filePathMatchMode',
                    'status': 'status',
                    'format_id': 'formatId',
                    'format_code': 'formatCode',
                    'type': 'type',
                    'parent_folder_id': 'parentFolderId',
                    'parent_folder_path': 'parentFolderPath',
                    'creation_date_after': 'creationDateAfter',
                    'creation_date_before': 'creationDateBefore',
                    'status_date_after': 'statusDateAfter',
                    'status_date_before': 'statusDateBefore',
                    'user_tag': 'userTag',
                    'user_tag_match_mode': 'userTagMatchMode',
                    'run_input_tag': 'runInputTag',
                    'run_input_tag_match_mode': 'runInputTagMatchMode',
                    'run_output_tag': 'runOutputTag',
                    'run_output_tag_match_mode': 'runOutputTagMatchMode',
                    'connector_tag': 'connectorTag',
                    'connector_tag_match_mode': 'connectorTagMatchMode',
                    'technical_tag': 'technicalTag',
                    'technical_tag_match_mode': 'technicalTagMatchMode',
                    'not_in_run': 'notInRun',
                    'instrument_run_id': 'instrumentRunId',
                    'page_offset': 'pageOffset',
                    'page_token': 'pageToken',
                    'page_size': 'pageSize',
                    'sort': 'sort',
                },
                'location_map': {
                    'project_id': 'path',
                    'sample_id': 'path',
                    'full_text': 'query',
                    'id': 'query',
                    'filename': 'query',
                    'filename_match_mode': 'query',
                    'file_path': 'query',
                    'file_path_match_mode': 'query',
                    'status': 'query',
                    'format_id': 'query',
                    'format_code': 'query',
                    'type': 'query',
                    'parent_folder_id': 'query',
                    'parent_folder_path': 'query',
                    'creation_date_after': 'query',
                    'creation_date_before': 'query',
                    'status_date_after': 'query',
                    'status_date_before': 'query',
                    'user_tag': 'query',
                    'user_tag_match_mode': 'query',
                    'run_input_tag': 'query',
                    'run_input_tag_match_mode': 'query',
                    'run_output_tag': 'query',
                    'run_output_tag_match_mode': 'query',
                    'connector_tag': 'query',
                    'connector_tag_match_mode': 'query',
                    'technical_tag': 'query',
                    'technical_tag_match_mode': 'query',
                    'not_in_run': 'query',
                    'instrument_run_id': 'query',
                    'page_offset': 'query',
                    'page_token': 'query',
                    'page_size': 'query',
                    'sort': 'query',
                },
                'collection_format_map': {
                    'id': 'multi',
                    'filename': 'multi',
                    'file_path': 'multi',
                    'status': 'multi',
                    'format_id': 'multi',
                    'format_code': 'multi',
                    'parent_folder_id': 'multi',
                    'user_tag': 'multi',
                    'run_input_tag': 'multi',
                    'run_output_tag': 'multi',
                    'connector_tag': 'multi',
                    'technical_tag': 'multi',
                    'instrument_run_id': 'multi',
                }
            },
            headers_map={
                'accept': [
                    'application/problem+json',
                    'application/vnd.illumina.v3+json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_sample_history_endpoint = _Endpoint(
            settings={
                'response_type': (SampleHistoryList,),
                'auth': [
                    'ApiKeyAuth',
                    'JwtAuth'
                ],
                'endpoint_path': '/api/projects/{projectId}/samples/{sampleId}/history',
                'operation_id': 'get_sample_history',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'project_id',
                    'sample_id',
                ],
                'required': [
                    'project_id',
                    'sample_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'project_id':
                        (str,),
                    'sample_id':
                        (str,),
                },
                'attribute_map': {
                    'project_id': 'projectId',
                    'sample_id': 'sampleId',
                },
                'location_map': {
                    'project_id': 'path',
                    'sample_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/problem+json',
                    'application/vnd.illumina.v3+json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_sample_metadata_field_endpoint = _Endpoint(
            settings={
                'response_type': (Field,),
                'auth': [
                    'ApiKeyAuth',
                    'JwtAuth'
                ],
                'endpoint_path': '/api/projects/{projectId}/samples/{sampleId}/metadata/field/{fieldId}',
                'operation_id': 'get_sample_metadata_field',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'project_id',
                    'sample_id',
                    'field_id',
                ],
                'required': [
                    'project_id',
                    'sample_id',
                    'field_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'project_id':
                        (str,),
                    'sample_id':
                        (str,),
                    'field_id':
                        (str,),
                },
                'attribute_map': {
                    'project_id': 'projectId',
                    'sample_id': 'sampleId',
                    'field_id': 'fieldId',
                },
                'location_map': {
                    'project_id': 'path',
                    'sample_id': 'path',
                    'field_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/problem+json',
                    'application/vnd.illumina.v3+json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_sample_metadata_field_count_endpoint = _Endpoint(
            settings={
                'response_type': (Field,),
                'auth': [
                    'ApiKeyAuth',
                    'JwtAuth'
                ],
                'endpoint_path': '/api/projects/{projectId}/samples/{sampleId}/metadata/{fieldId}/fieldCount',
                'operation_id': 'get_sample_metadata_field_count',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'project_id',
                    'sample_id',
                    'field_id',
                ],
                'required': [
                    'project_id',
                    'sample_id',
                    'field_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'project_id':
                        (str,),
                    'sample_id':
                        (str,),
                    'field_id':
                        (str,),
                },
                'attribute_map': {
                    'project_id': 'projectId',
                    'sample_id': 'sampleId',
                    'field_id': 'fieldId',
                },
                'location_map': {
                    'project_id': 'path',
                    'sample_id': 'path',
                    'field_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/problem+json',
                    'application/vnd.illumina.v3+json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.link_data_to_sample_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [
                    'ApiKeyAuth',
                    'JwtAuth'
                ],
                'endpoint_path': '/api/projects/{projectId}/samples/{sampleId}/data/{dataId}',
                'operation_id': 'link_data_to_sample',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'project_id',
                    'sample_id',
                    'data_id',
                ],
                'required': [
                    'project_id',
                    'sample_id',
                    'data_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'project_id':
                        (str,),
                    'sample_id':
                        (str,),
                    'data_id':
                        (str,),
                },
                'attribute_map': {
                    'project_id': 'projectId',
                    'sample_id': 'sampleId',
                    'data_id': 'dataId',
                },
                'location_map': {
                    'project_id': 'path',
                    'sample_id': 'path',
                    'data_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/problem+json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.link_sample_to_project_endpoint = _Endpoint(
            settings={
                'response_type': (ProjectSample,),
                'auth': [
                    'ApiKeyAuth',
                    'JwtAuth'
                ],
                'endpoint_path': '/api/projects/{projectId}/samples/{sampleId}',
                'operation_id': 'link_sample_to_project',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'project_id',
                    'sample_id',
                ],
                'required': [
                    'project_id',
                    'sample_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'project_id':
                        (str,),
                    'sample_id':
                        (str,),
                },
                'attribute_map': {
                    'project_id': 'projectId',
                    'sample_id': 'sampleId',
                },
                'location_map': {
                    'project_id': 'path',
                    'sample_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/problem+json',
                    'application/vnd.illumina.v3+json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.mark_sample_deleted_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [
                    'ApiKeyAuth',
                    'JwtAuth'
                ],
                'endpoint_path': '/api/projects/{projectId}/samples/{sampleId}:deleteMark',
                'operation_id': 'mark_sample_deleted',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'project_id',
                    'sample_id',
                ],
                'required': [
                    'project_id',
                    'sample_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'project_id':
                        (str,),
                    'sample_id':
                        (str,),
                },
                'attribute_map': {
                    'project_id': 'projectId',
                    'sample_id': 'sampleId',
                },
                'location_map': {
                    'project_id': 'path',
                    'sample_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/problem+json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.unlink_data_from_sample_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [
                    'ApiKeyAuth',
                    'JwtAuth'
                ],
                'endpoint_path': '/api/projects/{projectId}/samples/{sampleId}/data/{dataId}:unlink',
                'operation_id': 'unlink_data_from_sample',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'project_id',
                    'sample_id',
                    'data_id',
                ],
                'required': [
                    'project_id',
                    'sample_id',
                    'data_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'project_id':
                        (str,),
                    'sample_id':
                        (str,),
                    'data_id':
                        (str,),
                },
                'attribute_map': {
                    'project_id': 'projectId',
                    'sample_id': 'sampleId',
                    'data_id': 'dataId',
                },
                'location_map': {
                    'project_id': 'path',
                    'sample_id': 'path',
                    'data_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/problem+json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.unlink_sample_from_project_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [
                    'ApiKeyAuth',
                    'JwtAuth'
                ],
                'endpoint_path': '/api/projects/{projectId}/samples/{sampleId}:unlink',
                'operation_id': 'unlink_sample_from_project',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'project_id',
                    'sample_id',
                ],
                'required': [
                    'project_id',
                    'sample_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'project_id':
                        (str,),
                    'sample_id':
                        (str,),
                },
                'attribute_map': {
                    'project_id': 'projectId',
                    'sample_id': 'sampleId',
                },
                'location_map': {
                    'project_id': 'path',
                    'sample_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/problem+json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.update_project_sample_endpoint = _Endpoint(
            settings={
                'response_type': (ProjectSample,),
                'auth': [
                    'ApiKeyAuth',
                    'JwtAuth'
                ],
                'endpoint_path': '/api/projects/{projectId}/samples/{sampleId}',
                'operation_id': 'update_project_sample',
                'http_method': 'PUT',
                'servers': None,
            },
            params_map={
                'all': [
                    'project_id',
                    'sample_id',
                    'project_sample',
                    'if_match',
                ],
                'required': [
                    'project_id',
                    'sample_id',
                    'project_sample',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'project_id':
                        (str,),
                    'sample_id':
                        (str,),
                    'project_sample':
                        (ProjectSample,),
                    'if_match':
                        (str,),
                },
                'attribute_map': {
                    'project_id': 'projectId',
                    'sample_id': 'sampleId',
                    'if_match': 'If-Match',
                },
                'location_map': {
                    'project_id': 'path',
                    'sample_id': 'path',
                    'project_sample': 'body',
                    'if_match': 'header',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/problem+json',
                    'application/vnd.illumina.v3+json'
                ],
                'content_type': [
                    'application/vnd.illumina.v3+json',
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.update_sample_metadata_fields_endpoint = _Endpoint(
            settings={
                'response_type': (Sample,),
                'auth': [
                    'ApiKeyAuth',
                    'JwtAuth'
                ],
                'endpoint_path': '/api/projects/{projectId}/samples/{sampleId}/metadata:updateFields',
                'operation_id': 'update_sample_metadata_fields',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'project_id',
                    'sample_id',
                    'update_metadata',
                ],
                'required': [
                    'project_id',
                    'sample_id',
                    'update_metadata',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'project_id':
                        (str,),
                    'sample_id':
                        (str,),
                    'update_metadata':
                        (UpdateMetadata,),
                },
                'attribute_map': {
                    'project_id': 'projectId',
                    'sample_id': 'sampleId',
                },
                'location_map': {
                    'project_id': 'path',
                    'sample_id': 'path',
                    'update_metadata': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/problem+json',
                    'application/vnd.illumina.v3+json'
                ],
                'content_type': [
                    'application/vnd.illumina.v3+json',
                    'application/json'
                ]
            },
            api_client=api_client
        )

    def add_metadata_model_to_sample(
        self,
        project_id,
        sample_id,
        metadata_model_id,
        **kwargs
    ):
        """Add a metadata model to a sample.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.add_metadata_model_to_sample(project_id, sample_id, metadata_model_id, async_req=True)
        >>> result = thread.get()

        Args:
            project_id (str):
            sample_id (str): The ID of the sample
            metadata_model_id (str): The ID of the metadata model

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['project_id'] = \
            project_id
        kwargs['sample_id'] = \
            sample_id
        kwargs['metadata_model_id'] = \
            metadata_model_id
        return self.add_metadata_model_to_sample_endpoint.call_with_http_info(**kwargs)

    def complete_project_sample(
        self,
        project_id,
        sample_id,
        **kwargs
    ):
        """Completes the sample after data has been linked to it.  # noqa: E501

        Completes the sample after data has been linked to it. The sample status will be set to 'Available' and a sample completed event will be triggered as well.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.complete_project_sample(project_id, sample_id, async_req=True)
        >>> result = thread.get()

        Args:
            project_id (str):
            sample_id (str):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['project_id'] = \
            project_id
        kwargs['sample_id'] = \
            sample_id
        return self.complete_project_sample_endpoint.call_with_http_info(**kwargs)

    def create_sample_in_project(
        self,
        project_id,
        create_sample,
        **kwargs
    ):
        """Create a new sample in this project  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_sample_in_project(project_id, create_sample, async_req=True)
        >>> result = thread.get()

        Args:
            project_id (str):
            create_sample (CreateSample):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            ProjectSample
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['project_id'] = \
            project_id
        kwargs['create_sample'] = \
            create_sample
        return self.create_sample_in_project_endpoint.call_with_http_info(**kwargs)

    def deep_delete_sample(
        self,
        project_id,
        sample_id,
        **kwargs
    ):
        """Delete a sample together with all of its data.  # noqa: E501

        Endpoint deleting a sample together with all of its data.This is a non-RESTful endpoint, as the path of this endpoint is not representing a REST resource.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.deep_delete_sample(project_id, sample_id, async_req=True)
        >>> result = thread.get()

        Args:
            project_id (str):
            sample_id (str): The ID of the sample

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['project_id'] = \
            project_id
        kwargs['sample_id'] = \
            sample_id
        return self.deep_delete_sample_endpoint.call_with_http_info(**kwargs)

    def delete_and_unlink_sample(
        self,
        project_id,
        sample_id,
        **kwargs
    ):
        """Delete a sample and unlink its data.  # noqa: E501

        Endpoint for deleting a sample while unlinking its data.This is a non-RESTful endpoint, as the path of this endpoint is not representing a REST resource.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_and_unlink_sample(project_id, sample_id, async_req=True)
        >>> result = thread.get()

        Args:
            project_id (str):
            sample_id (str): The ID of the sample

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['project_id'] = \
            project_id
        kwargs['sample_id'] = \
            sample_id
        return self.delete_and_unlink_sample_endpoint.call_with_http_info(**kwargs)

    def delete_sample_with_input(
        self,
        project_id,
        sample_id,
        **kwargs
    ):
        """Delete a sample as well as its input data.  # noqa: E501

        Endpoint for deleting a sample as well as its input data.This is a non-RESTful endpoint, as the path of this endpoint is not representing a REST resource.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_sample_with_input(project_id, sample_id, async_req=True)
        >>> result = thread.get()

        Args:
            project_id (str):
            sample_id (str): The ID of the sample

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['project_id'] = \
            project_id
        kwargs['sample_id'] = \
            sample_id
        return self.delete_sample_with_input_endpoint.call_with_http_info(**kwargs)

    def get_project_sample(
        self,
        project_id,
        sample_id,
        **kwargs
    ):
        """Retrieve a project sample.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_project_sample(project_id, sample_id, async_req=True)
        >>> result = thread.get()

        Args:
            project_id (str):
            sample_id (str): The ID of the sample

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            ProjectSample
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['project_id'] = \
            project_id
        kwargs['sample_id'] = \
            sample_id
        return self.get_project_sample_endpoint.call_with_http_info(**kwargs)

    def get_project_sample_analyses(
        self,
        project_id,
        sample_id,
        **kwargs
    ):
        """Retrieve the list of analyses.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_project_sample_analyses(project_id, sample_id, async_req=True)
        >>> result = thread.get()

        Args:
            project_id (str):
            sample_id (str): The ID of the sample

        Keyword Args:
            reference (str): The reference to filter on.. [optional]
            userreference (str): The user-reference to filter on.. [optional]
            status (str): The status to filter on.. [optional]
            usertag (str): The user-tags to filter on.. [optional]
            technicaltag (str): The technical-tags to filter on.. [optional]
            referencetag (str): The reference-data-tags to filter on.. [optional]
            page_offset (str): [only use with offset-based paging]<br>The amount of rows to skip in the result. Ideally this is a multiple of the size parameter. Offset-based pagination has a result limit of 200K rows and does not guarantee unique results across pages. [optional]
            page_token (str): [only use with cursor-based paging]<br>The cursor to get subsequent results. The value to use is returned in the result when using cursor-based pagination. Cursor-based pagination guarantees complete and unique results across all pages.. [optional]
            page_size (str): [can be used with both offset- and cursor-based paging]<br>The amount of rows to return. Use in combination with the offset (when using offset-based pagination) or cursor (when using cursor-based pagination) parameter to get subsequent results. [optional]
            sort (str): [only use with offset-based paging]<br>Which field to order the results by. The default order is ascending, suffix with ' desc' to sort descending (suffix ' asc' also works for ascending). Multiple values should be separated with commas. An example: \"?sort=dateCreated, lastName desc\"  The attributes for which sorting is supported: - reference - userReference - pipeline - status - startDate - endDate - summary . [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            AnalysisPagedList
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['project_id'] = \
            project_id
        kwargs['sample_id'] = \
            sample_id
        return self.get_project_sample_analyses_endpoint.call_with_http_info(**kwargs)

    def get_project_samples(
        self,
        project_id,
        find_project_samples,
        **kwargs
    ):
        """Retrieve project samples.  # noqa: E501

        Endpoint for retrieving project samples. This is a non-RESTful endpoint, as the path of this endpoint is not representing a REST resource.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_project_samples(project_id, find_project_samples, async_req=True)
        >>> result = thread.get()

        Args:
            project_id (str):
            find_project_samples (FindProjectSamples):

        Keyword Args:
            page_offset (str): [only use with offset-based paging]<br>The amount of rows to skip in the result. Ideally this is a multiple of the size parameter. Offset-based pagination has a result limit of 200K rows and does not guarantee unique results across pages. [optional]
            page_token (str): [only use with cursor-based paging]<br>The cursor to get subsequent results. The value to use is returned in the result when using cursor-based pagination. Cursor-based pagination guarantees complete and unique results across all pages.. [optional]
            page_size (str): [can be used with both offset- and cursor-based paging]<br>The amount of rows to return. Use in combination with the offset (when using offset-based pagination) or cursor (when using cursor-based pagination) parameter to get subsequent results. [optional]
            sort (str): [only use with offset-based paging]<br>Which field to order the results by. The default order is ascending, suffix with ' desc' to sort descending (suffix ' asc' also works for ascending). Multiple values should be separated with commas. An example: \"?sort=dateCreated, lastName desc\" The attributes for which sorting is supported: - timeCreated - timeModified - name - description - metadataValid - status. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            ProjectSamplePagedList
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['project_id'] = \
            project_id
        kwargs['find_project_samples'] = \
            find_project_samples
        return self.get_project_samples_endpoint.call_with_http_info(**kwargs)

    def get_projects_for_sample(
        self,
        project_id,
        sample_id,
        **kwargs
    ):
        """Retrieve a list of projects for this sample.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_projects_for_sample(project_id, sample_id, async_req=True)
        >>> result = thread.get()

        Args:
            project_id (str):
            sample_id (str): The ID of the sample

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            ProjectList
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['project_id'] = \
            project_id
        kwargs['sample_id'] = \
            sample_id
        return self.get_projects_for_sample_endpoint.call_with_http_info(**kwargs)

    def get_sample_data_list(
        self,
        project_id,
        sample_id,
        **kwargs
    ):
        """Retrieve the list of sample data.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_sample_data_list(project_id, sample_id, async_req=True)
        >>> result = thread.get()

        Args:
            project_id (str):
            sample_id (str): The ID of the sample to retrieve data for

        Keyword Args:
            full_text (str): To search through multiple fields of data.. [optional]
            id ([str]): The ids to filter on. This will always match exact.. [optional]
            filename ([str]): The filenames to filter on. The filenameMatchMode-parameter determines how the filtering is done.. [optional]
            filename_match_mode (str): How the filenames are filtered. . [optional]
            file_path ([str]): The paths of the files to filter on.. [optional]
            file_path_match_mode (str): How the file paths are filtered:   - STARTS_WITH_CASE_INSENSITIVE: Filters the file path to start with the value of the 'filePath' parameter, regardless of upper/lower casing. This allows e.g. listing all data in a folder and all it's sub-folders (recursively).  - FULL_CASE_INSENSITIVE: Filters the file path to fully match the value of the 'filePath' parameter, regardless of upper/lower casing. Note that this can result in multiple results if e.g. two files exist with the same filename but different casing (abc.txt and ABC.txt).. [optional] if omitted the server will use the default value of "STARTS_WITH_CASE_INSENSITIVE"
            status ([str]): The statuses to filter on.. [optional]
            format_id ([str]): The IDs of the formats to filter on.. [optional]
            format_code ([str]): The codes of the formats to filter on.. [optional]
            type (str): The type to filter on.. [optional]
            parent_folder_id ([str]): The IDs of parents folders to filter on. Lists all files and folders within the folder for the given ID, non-recursively.. [optional]
            parent_folder_path (str): The full path of the parent folder. Should start and end with a '/'. Lists all files and folders within the folder for the given path, non-recursively. This can be used to browse through the hierarchical tree of folders, e.g. traversing one level up can be done by removing the last part of the path.. [optional]
            creation_date_after (datetime): The date after which the data is created. Format: yyyy-MM-dd'T'HH:mm:ss'Z' eg: 2021-01-30T08:30:00Z. [optional]
            creation_date_before (datetime): The date before which the data is created. Format: yyyy-MM-dd'T'HH:mm:ss'Z' eg: 2021-01-30T08:30:00Z. [optional]
            status_date_after (datetime): The date after which the status has been updated. Format: yyyy-MM-dd'T'HH:mm:ss'Z' eg: 2021-01-30T08:30:00Z. [optional]
            status_date_before (datetime): The date before which the status has been updated. Format: yyyy-MM-dd'T'HH:mm:ss'Z' eg: 2021-01-30T08:30:00Z. [optional]
            user_tag ([str]): The usertags to filter on. The userTagMatchMode-parameter determines how the filtering is done.. [optional]
            user_tag_match_mode (str): How the usertags are filtered. . [optional]
            run_input_tag ([str]): The runInputTags to filter on. The runInputTagMatchMode-parameter determines how the filtering is done.. [optional]
            run_input_tag_match_mode (str): How the runInputTags are filtered. . [optional]
            run_output_tag ([str]): The runOutputTags to filter on. The runOutputTagMatchMode-parameter determines how the filtering is done.. [optional]
            run_output_tag_match_mode (str): How the runOutputTags are filtered. . [optional]
            connector_tag ([str]): The connectorTags to filter on. The connectorTagMatchMode-parameter determines how the filtering is done.. [optional]
            connector_tag_match_mode (str): How the connectorTags are filtered. . [optional]
            technical_tag ([str]): The technicalTags to filter on. The techTagMatchMode-parameter determines how the filtering is done.. [optional]
            technical_tag_match_mode (str): How the technicalTags are filtered. . [optional]
            not_in_run (bool): When set to true, the data will be filtered on data which is not used in a run.. [optional]
            instrument_run_id ([str]): The instrument run IDs of the sequencing runs to filter on.. [optional]
            page_offset (str): [only use with offset-based paging]<br>The amount of rows to skip in the result. Ideally this is a multiple of the size parameter. Offset-based pagination has a result limit of 200K rows and does not guarantee unique results across pages. [optional]
            page_token (str): [only use with cursor-based paging]<br>The cursor to get subsequent results. The value to use is returned in the result when using cursor-based pagination. Cursor-based pagination guarantees complete and unique results across all pages.. [optional]
            page_size (str): [can be used with both offset- and cursor-based paging]<br>The amount of rows to return. Use in combination with the offset (when using offset-based pagination) or cursor (when using cursor-based pagination) parameter to get subsequent results. [optional]
            sort (str): [only use with offset-based paging]<br>Which field to order the results by. The default order is ascending, suffix with ' desc' to sort descending (suffix ' asc' also works for ascending). Multiple values should be separated with commas. An example: \"?sort=dateCreated, lastName desc\"  The attributes for which sorting is supported: - timeCreated - timeModified - name - path - fileSizeInBytes - status - format - dataType - willBeArchivedAt - willBeDeletedAt. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            DataList
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['project_id'] = \
            project_id
        kwargs['sample_id'] = \
            sample_id
        return self.get_sample_data_list_endpoint.call_with_http_info(**kwargs)

    def get_sample_history(
        self,
        project_id,
        sample_id,
        **kwargs
    ):
        """Retrieve sample history.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_sample_history(project_id, sample_id, async_req=True)
        >>> result = thread.get()

        Args:
            project_id (str):
            sample_id (str): The ID of the sample

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            SampleHistoryList
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['project_id'] = \
            project_id
        kwargs['sample_id'] = \
            sample_id
        return self.get_sample_history_endpoint.call_with_http_info(**kwargs)

    def get_sample_metadata_field(
        self,
        project_id,
        sample_id,
        field_id,
        **kwargs
    ):
        """Retrieve a metadata field.  # noqa: E501

        Returns a list of values for the field with identifier fieldId belonging to the sample with identifier sampleId. If the field is a group field that can occur more than once or belongs to a group field that can occur more than once the return value will have one entry in the list for each occurrence. If not the return value will be a single value list  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_sample_metadata_field(project_id, sample_id, field_id, async_req=True)
        >>> result = thread.get()

        Args:
            project_id (str):
            sample_id (str): The ID of the sample
            field_id (str): The ID of the field

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            Field
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['project_id'] = \
            project_id
        kwargs['sample_id'] = \
            sample_id
        kwargs['field_id'] = \
            field_id
        return self.get_sample_metadata_field_endpoint.call_with_http_info(**kwargs)

    def get_sample_metadata_field_count(
        self,
        project_id,
        sample_id,
        field_id,
        **kwargs
    ):
        """Retrieves the number of occurrences of a given field.  # noqa: E501

        Returns a list of values for the field with identifier fieldId belonging to the sample with identifier sampleId. If the field is a group field that can occur more than once or belongs to a group field that can occur more than once the return value will have one entry in the list for each occurrence. If not the return value will be a single value list  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_sample_metadata_field_count(project_id, sample_id, field_id, async_req=True)
        >>> result = thread.get()

        Args:
            project_id (str):
            sample_id (str): The ID of the sample
            field_id (str): The ID of the field

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            Field
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['project_id'] = \
            project_id
        kwargs['sample_id'] = \
            sample_id
        kwargs['field_id'] = \
            field_id
        return self.get_sample_metadata_field_count_endpoint.call_with_http_info(**kwargs)

    def link_data_to_sample(
        self,
        project_id,
        sample_id,
        data_id,
        **kwargs
    ):
        """Link data to a sample.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.link_data_to_sample(project_id, sample_id, data_id, async_req=True)
        >>> result = thread.get()

        Args:
            project_id (str):
            sample_id (str): The ID of the sample
            data_id (str): The ID of the data to link

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['project_id'] = \
            project_id
        kwargs['sample_id'] = \
            sample_id
        kwargs['data_id'] = \
            data_id
        return self.link_data_to_sample_endpoint.call_with_http_info(**kwargs)

    def link_sample_to_project(
        self,
        project_id,
        sample_id,
        **kwargs
    ):
        """Link a sample to a project.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.link_sample_to_project(project_id, sample_id, async_req=True)
        >>> result = thread.get()

        Args:
            project_id (str):
            sample_id (str):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            ProjectSample
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['project_id'] = \
            project_id
        kwargs['sample_id'] = \
            sample_id
        return self.link_sample_to_project_endpoint.call_with_http_info(**kwargs)

    def mark_sample_deleted(
        self,
        project_id,
        sample_id,
        **kwargs
    ):
        """Mark a sample deleted.  # noqa: E501

        Endpoint for marking a sample as deleted.This is a non-RESTful endpoint, as the path of this endpoint is not representing a REST resource.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.mark_sample_deleted(project_id, sample_id, async_req=True)
        >>> result = thread.get()

        Args:
            project_id (str):
            sample_id (str): The ID of the sample

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['project_id'] = \
            project_id
        kwargs['sample_id'] = \
            sample_id
        return self.mark_sample_deleted_endpoint.call_with_http_info(**kwargs)

    def unlink_data_from_sample(
        self,
        project_id,
        sample_id,
        data_id,
        **kwargs
    ):
        """Unlink data from a sample.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.unlink_data_from_sample(project_id, sample_id, data_id, async_req=True)
        >>> result = thread.get()

        Args:
            project_id (str):
            sample_id (str): The ID of the sample
            data_id (str): The ID of the data to unlink

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['project_id'] = \
            project_id
        kwargs['sample_id'] = \
            sample_id
        kwargs['data_id'] = \
            data_id
        return self.unlink_data_from_sample_endpoint.call_with_http_info(**kwargs)

    def unlink_sample_from_project(
        self,
        project_id,
        sample_id,
        **kwargs
    ):
        """Unlink a sample from a project.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.unlink_sample_from_project(project_id, sample_id, async_req=True)
        >>> result = thread.get()

        Args:
            project_id (str):
            sample_id (str):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['project_id'] = \
            project_id
        kwargs['sample_id'] = \
            sample_id
        return self.unlink_sample_from_project_endpoint.call_with_http_info(**kwargs)

    def update_project_sample(
        self,
        project_id,
        sample_id,
        project_sample,
        **kwargs
    ):
        """Update a project sample.  # noqa: E501

        Fields which can be updated: - sample.name - sample.description - sample.status - sample.tags  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_project_sample(project_id, sample_id, project_sample, async_req=True)
        >>> result = thread.get()

        Args:
            project_id (str):
            sample_id (str):
            project_sample (ProjectSample):

        Keyword Args:
            if_match (str): Optional header parameter to enable conflict exposure. If the client provides this header, then it must contains the client's most recent value of the 'ETag' response header, and the server will respond with a 409 code if it detects a conflict. If the client does not provide this header, then the server will not do a conflict check, which means that as a client you can override the resource even when the server has a more recent version.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            ProjectSample
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['project_id'] = \
            project_id
        kwargs['sample_id'] = \
            sample_id
        kwargs['project_sample'] = \
            project_sample
        return self.update_project_sample_endpoint.call_with_http_info(**kwargs)

    def update_sample_metadata_fields(
        self,
        project_id,
        sample_id,
        update_metadata,
        **kwargs
    ):
        """Update metadata fields.  # noqa: E501

        Endpoint for updating metadata fields.This is a non-RESTful endpoint, as the path of this endpoint is not representing a REST resource.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_sample_metadata_fields(project_id, sample_id, update_metadata, async_req=True)
        >>> result = thread.get()

        Args:
            project_id (str):
            sample_id (str):
            update_metadata (UpdateMetadata):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            Sample
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['project_id'] = \
            project_id
        kwargs['sample_id'] = \
            sample_id
        kwargs['update_metadata'] = \
            update_metadata
        return self.update_sample_metadata_fields_endpoint.call_with_http_info(**kwargs)




# coding: utf-8

"""
    Genomic Data Store Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from libica.openapi.libgds.configuration import Configuration


class FileResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'volume_metadata': 'object',
        'copy_job_id': 'str',
        'job_id': 'str',
        'id': 'str',
        'name': 'str',
        'volume_id': 'str',
        'parent_folder_id': 'str',
        'volume_name': 'str',
        'volume_configuration_name': 'str',
        'type': 'str',
        'tenant_id': 'str',
        'sub_tenant_id': 'str',
        'path': 'str',
        'time_created': 'datetime',
        'created_by': 'str',
        'time_modified': 'datetime',
        'modified_by': 'str',
        'inherited_acl': 'list[str]',
        'urn': 'str',
        'size_in_bytes': 'int',
        'metadata': 'object',
        'is_uploaded': 'bool',
        'archive_status': 'ArchiveStatuses',
        'time_archived': 'datetime',
        'storage_tier': 'StorageTier',
        'e_tag': 'str',
        'format': 'str',
        'format_edam': 'str',
        'status': 'FileStatus',
        'life_cycle': 'FileLifeCycleSettings',
        'restore_expiration': 'datetime',
        'presigned_url': 'str',
        'object_store_access': 'ObjectStoreAccess'
    }

    attribute_map = {
        'volume_metadata': 'volumeMetadata',
        'copy_job_id': 'copyJobId',
        'job_id': 'jobId',
        'id': 'id',
        'name': 'name',
        'volume_id': 'volumeId',
        'parent_folder_id': 'parentFolderId',
        'volume_name': 'volumeName',
        'volume_configuration_name': 'volumeConfigurationName',
        'type': 'type',
        'tenant_id': 'tenantId',
        'sub_tenant_id': 'subTenantId',
        'path': 'path',
        'time_created': 'timeCreated',
        'created_by': 'createdBy',
        'time_modified': 'timeModified',
        'modified_by': 'modifiedBy',
        'inherited_acl': 'inheritedAcl',
        'urn': 'urn',
        'size_in_bytes': 'sizeInBytes',
        'metadata': 'metadata',
        'is_uploaded': 'isUploaded',
        'archive_status': 'archiveStatus',
        'time_archived': 'timeArchived',
        'storage_tier': 'storageTier',
        'e_tag': 'eTag',
        'format': 'format',
        'format_edam': 'formatEdam',
        'status': 'status',
        'life_cycle': 'lifeCycle',
        'restore_expiration': 'restoreExpiration',
        'presigned_url': 'presignedUrl',
        'object_store_access': 'objectStoreAccess'
    }

    def __init__(self, volume_metadata=None, copy_job_id=None, job_id=None, id=None, name=None, volume_id=None, parent_folder_id=None, volume_name=None, volume_configuration_name=None, type=None, tenant_id=None, sub_tenant_id=None, path=None, time_created=None, created_by=None, time_modified=None, modified_by=None, inherited_acl=None, urn=None, size_in_bytes=None, metadata=None, is_uploaded=None, archive_status=None, time_archived=None, storage_tier=None, e_tag=None, format=None, format_edam=None, status=None, life_cycle=None, restore_expiration=None, presigned_url=None, object_store_access=None, local_vars_configuration=None):  # noqa: E501
        """FileResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._volume_metadata = None
        self._copy_job_id = None
        self._job_id = None
        self._id = None
        self._name = None
        self._volume_id = None
        self._parent_folder_id = None
        self._volume_name = None
        self._volume_configuration_name = None
        self._type = None
        self._tenant_id = None
        self._sub_tenant_id = None
        self._path = None
        self._time_created = None
        self._created_by = None
        self._time_modified = None
        self._modified_by = None
        self._inherited_acl = None
        self._urn = None
        self._size_in_bytes = None
        self._metadata = None
        self._is_uploaded = None
        self._archive_status = None
        self._time_archived = None
        self._storage_tier = None
        self._e_tag = None
        self._format = None
        self._format_edam = None
        self._status = None
        self._life_cycle = None
        self._restore_expiration = None
        self._presigned_url = None
        self._object_store_access = None
        self.discriminator = None

        if volume_metadata is not None:
            self.volume_metadata = volume_metadata
        if copy_job_id is not None:
            self.copy_job_id = copy_job_id
        if job_id is not None:
            self.job_id = job_id
        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if volume_id is not None:
            self.volume_id = volume_id
        if parent_folder_id is not None:
            self.parent_folder_id = parent_folder_id
        if volume_name is not None:
            self.volume_name = volume_name
        if volume_configuration_name is not None:
            self.volume_configuration_name = volume_configuration_name
        if type is not None:
            self.type = type
        if tenant_id is not None:
            self.tenant_id = tenant_id
        if sub_tenant_id is not None:
            self.sub_tenant_id = sub_tenant_id
        if path is not None:
            self.path = path
        if time_created is not None:
            self.time_created = time_created
        if created_by is not None:
            self.created_by = created_by
        if time_modified is not None:
            self.time_modified = time_modified
        if modified_by is not None:
            self.modified_by = modified_by
        if inherited_acl is not None:
            self.inherited_acl = inherited_acl
        if urn is not None:
            self.urn = urn
        if size_in_bytes is not None:
            self.size_in_bytes = size_in_bytes
        if metadata is not None:
            self.metadata = metadata
        if is_uploaded is not None:
            self.is_uploaded = is_uploaded
        if archive_status is not None:
            self.archive_status = archive_status
        if time_archived is not None:
            self.time_archived = time_archived
        if storage_tier is not None:
            self.storage_tier = storage_tier
        if e_tag is not None:
            self.e_tag = e_tag
        if format is not None:
            self.format = format
        if format_edam is not None:
            self.format_edam = format_edam
        if status is not None:
            self.status = status
        if life_cycle is not None:
            self.life_cycle = life_cycle
        if restore_expiration is not None:
            self.restore_expiration = restore_expiration
        if presigned_url is not None:
            self.presigned_url = presigned_url
        if object_store_access is not None:
            self.object_store_access = object_store_access

    @property
    def volume_metadata(self):
        """Gets the volume_metadata of this FileResponse.  # noqa: E501

        Metadata about this file's volume  # noqa: E501

        :return: The volume_metadata of this FileResponse.  # noqa: E501
        :rtype: object
        """
        return self._volume_metadata

    @volume_metadata.setter
    def volume_metadata(self, volume_metadata):
        """Sets the volume_metadata of this FileResponse.

        Metadata about this file's volume  # noqa: E501

        :param volume_metadata: The volume_metadata of this FileResponse.  # noqa: E501
        :type: object
        """

        self._volume_metadata = volume_metadata

    @property
    def copy_job_id(self):
        """Gets the copy_job_id of this FileResponse.  # noqa: E501

        Job that copied the file  # noqa: E501

        :return: The copy_job_id of this FileResponse.  # noqa: E501
        :rtype: str
        """
        return self._copy_job_id

    @copy_job_id.setter
    def copy_job_id(self, copy_job_id):
        """Sets the copy_job_id of this FileResponse.

        Job that copied the file  # noqa: E501

        :param copy_job_id: The copy_job_id of this FileResponse.  # noqa: E501
        :type: str
        """

        self._copy_job_id = copy_job_id

    @property
    def job_id(self):
        """Gets the job_id of this FileResponse.  # noqa: E501

        Job that performed operation on the file  # noqa: E501

        :return: The job_id of this FileResponse.  # noqa: E501
        :rtype: str
        """
        return self._job_id

    @job_id.setter
    def job_id(self, job_id):
        """Sets the job_id of this FileResponse.

        Job that performed operation on the file  # noqa: E501

        :param job_id: The job_id of this FileResponse.  # noqa: E501
        :type: str
        """

        self._job_id = job_id

    @property
    def id(self):
        """Gets the id of this FileResponse.  # noqa: E501

        A unique identifier for this File  # noqa: E501

        :return: The id of this FileResponse.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this FileResponse.

        A unique identifier for this File  # noqa: E501

        :param id: The id of this FileResponse.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this FileResponse.  # noqa: E501

        The name of this File  # noqa: E501

        :return: The name of this FileResponse.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this FileResponse.

        The name of this File  # noqa: E501

        :param name: The name of this FileResponse.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def volume_id(self):
        """Gets the volume_id of this FileResponse.  # noqa: E501

        The unique identifier of the volume where the file resides  # noqa: E501

        :return: The volume_id of this FileResponse.  # noqa: E501
        :rtype: str
        """
        return self._volume_id

    @volume_id.setter
    def volume_id(self, volume_id):
        """Sets the volume_id of this FileResponse.

        The unique identifier of the volume where the file resides  # noqa: E501

        :param volume_id: The volume_id of this FileResponse.  # noqa: E501
        :type: str
        """

        self._volume_id = volume_id

    @property
    def parent_folder_id(self):
        """Gets the parent_folder_id of this FileResponse.  # noqa: E501

        The unique identifier of the folder where the file resides  # noqa: E501

        :return: The parent_folder_id of this FileResponse.  # noqa: E501
        :rtype: str
        """
        return self._parent_folder_id

    @parent_folder_id.setter
    def parent_folder_id(self, parent_folder_id):
        """Sets the parent_folder_id of this FileResponse.

        The unique identifier of the folder where the file resides  # noqa: E501

        :param parent_folder_id: The parent_folder_id of this FileResponse.  # noqa: E501
        :type: str
        """

        self._parent_folder_id = parent_folder_id

    @property
    def volume_name(self):
        """Gets the volume_name of this FileResponse.  # noqa: E501

        The name of the volume where the file resides  # noqa: E501

        :return: The volume_name of this FileResponse.  # noqa: E501
        :rtype: str
        """
        return self._volume_name

    @volume_name.setter
    def volume_name(self, volume_name):
        """Sets the volume_name of this FileResponse.

        The name of the volume where the file resides  # noqa: E501

        :param volume_name: The volume_name of this FileResponse.  # noqa: E501
        :type: str
        """

        self._volume_name = volume_name

    @property
    def volume_configuration_name(self):
        """Gets the volume_configuration_name of this FileResponse.  # noqa: E501

        The name of the volume configuration (BYOB only)  # noqa: E501

        :return: The volume_configuration_name of this FileResponse.  # noqa: E501
        :rtype: str
        """
        return self._volume_configuration_name

    @volume_configuration_name.setter
    def volume_configuration_name(self, volume_configuration_name):
        """Sets the volume_configuration_name of this FileResponse.

        The name of the volume configuration (BYOB only)  # noqa: E501

        :param volume_configuration_name: The volume_configuration_name of this FileResponse.  # noqa: E501
        :type: str
        """

        self._volume_configuration_name = volume_configuration_name

    @property
    def type(self):
        """Gets the type of this FileResponse.  # noqa: E501

        The type of the File  # noqa: E501

        :return: The type of this FileResponse.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this FileResponse.

        The type of the File  # noqa: E501

        :param type: The type of this FileResponse.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def tenant_id(self):
        """Gets the tenant_id of this FileResponse.  # noqa: E501

        The unique identifier for this File's Tenant  # noqa: E501

        :return: The tenant_id of this FileResponse.  # noqa: E501
        :rtype: str
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this FileResponse.

        The unique identifier for this File's Tenant  # noqa: E501

        :param tenant_id: The tenant_id of this FileResponse.  # noqa: E501
        :type: str
        """

        self._tenant_id = tenant_id

    @property
    def sub_tenant_id(self):
        """Gets the sub_tenant_id of this FileResponse.  # noqa: E501

        The unique identifier for this File's Sub Tenant  # noqa: E501

        :return: The sub_tenant_id of this FileResponse.  # noqa: E501
        :rtype: str
        """
        return self._sub_tenant_id

    @sub_tenant_id.setter
    def sub_tenant_id(self, sub_tenant_id):
        """Sets the sub_tenant_id of this FileResponse.

        The unique identifier for this File's Sub Tenant  # noqa: E501

        :param sub_tenant_id: The sub_tenant_id of this FileResponse.  # noqa: E501
        :type: str
        """

        self._sub_tenant_id = sub_tenant_id

    @property
    def path(self):
        """Gets the path of this FileResponse.  # noqa: E501

        The (GDS) path to this File  # noqa: E501

        :return: The path of this FileResponse.  # noqa: E501
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this FileResponse.

        The (GDS) path to this File  # noqa: E501

        :param path: The path of this FileResponse.  # noqa: E501
        :type: str
        """

        self._path = path

    @property
    def time_created(self):
        """Gets the time_created of this FileResponse.  # noqa: E501

        The date & time this File was created, in GDS  # noqa: E501

        :return: The time_created of this FileResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """Sets the time_created of this FileResponse.

        The date & time this File was created, in GDS  # noqa: E501

        :param time_created: The time_created of this FileResponse.  # noqa: E501
        :type: datetime
        """

        self._time_created = time_created

    @property
    def created_by(self):
        """Gets the created_by of this FileResponse.  # noqa: E501

        The creator of this File  # noqa: E501

        :return: The created_by of this FileResponse.  # noqa: E501
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this FileResponse.

        The creator of this File  # noqa: E501

        :param created_by: The created_by of this FileResponse.  # noqa: E501
        :type: str
        """

        self._created_by = created_by

    @property
    def time_modified(self):
        """Gets the time_modified of this FileResponse.  # noqa: E501

        The date & time this File was updated, in GDS  # noqa: E501

        :return: The time_modified of this FileResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._time_modified

    @time_modified.setter
    def time_modified(self, time_modified):
        """Sets the time_modified of this FileResponse.

        The date & time this File was updated, in GDS  # noqa: E501

        :param time_modified: The time_modified of this FileResponse.  # noqa: E501
        :type: datetime
        """

        self._time_modified = time_modified

    @property
    def modified_by(self):
        """Gets the modified_by of this FileResponse.  # noqa: E501

        The updator of this File  # noqa: E501

        :return: The modified_by of this FileResponse.  # noqa: E501
        :rtype: str
        """
        return self._modified_by

    @modified_by.setter
    def modified_by(self, modified_by):
        """Sets the modified_by of this FileResponse.

        The updator of this File  # noqa: E501

        :param modified_by: The modified_by of this FileResponse.  # noqa: E501
        :type: str
        """

        self._modified_by = modified_by

    @property
    def inherited_acl(self):
        """Gets the inherited_acl of this FileResponse.  # noqa: E501

        The inherited list of Id(s) that have access to this File  # noqa: E501

        :return: The inherited_acl of this FileResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._inherited_acl

    @inherited_acl.setter
    def inherited_acl(self, inherited_acl):
        """Sets the inherited_acl of this FileResponse.

        The inherited list of Id(s) that have access to this File  # noqa: E501

        :param inherited_acl: The inherited_acl of this FileResponse.  # noqa: E501
        :type: list[str]
        """

        self._inherited_acl = inherited_acl

    @property
    def urn(self):
        """Gets the urn of this FileResponse.  # noqa: E501

        The Universal Resource Name, unique to this File  # noqa: E501

        :return: The urn of this FileResponse.  # noqa: E501
        :rtype: str
        """
        return self._urn

    @urn.setter
    def urn(self, urn):
        """Sets the urn of this FileResponse.

        The Universal Resource Name, unique to this File  # noqa: E501

        :param urn: The urn of this FileResponse.  # noqa: E501
        :type: str
        """

        self._urn = urn

    @property
    def size_in_bytes(self):
        """Gets the size_in_bytes of this FileResponse.  # noqa: E501

        The File's Size in bytes  # noqa: E501

        :return: The size_in_bytes of this FileResponse.  # noqa: E501
        :rtype: int
        """
        return self._size_in_bytes

    @size_in_bytes.setter
    def size_in_bytes(self, size_in_bytes):
        """Sets the size_in_bytes of this FileResponse.

        The File's Size in bytes  # noqa: E501

        :param size_in_bytes: The size_in_bytes of this FileResponse.  # noqa: E501
        :type: int
        """

        self._size_in_bytes = size_in_bytes

    @property
    def metadata(self):
        """Gets the metadata of this FileResponse.  # noqa: E501

        Metadata about this File  # noqa: E501

        :return: The metadata of this FileResponse.  # noqa: E501
        :rtype: object
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this FileResponse.

        Metadata about this File  # noqa: E501

        :param metadata: The metadata of this FileResponse.  # noqa: E501
        :type: object
        """

        self._metadata = metadata

    @property
    def is_uploaded(self):
        """Gets the is_uploaded of this FileResponse.  # noqa: E501

        The current upload state of the File  # noqa: E501

        :return: The is_uploaded of this FileResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_uploaded

    @is_uploaded.setter
    def is_uploaded(self, is_uploaded):
        """Sets the is_uploaded of this FileResponse.

        The current upload state of the File  # noqa: E501

        :param is_uploaded: The is_uploaded of this FileResponse.  # noqa: E501
        :type: bool
        """

        self._is_uploaded = is_uploaded

    @property
    def archive_status(self):
        """Gets the archive_status of this FileResponse.  # noqa: E501


        :return: The archive_status of this FileResponse.  # noqa: E501
        :rtype: ArchiveStatuses
        """
        return self._archive_status

    @archive_status.setter
    def archive_status(self, archive_status):
        """Sets the archive_status of this FileResponse.


        :param archive_status: The archive_status of this FileResponse.  # noqa: E501
        :type: ArchiveStatuses
        """

        self._archive_status = archive_status

    @property
    def time_archived(self):
        """Gets the time_archived of this FileResponse.  # noqa: E501

        The date & time this File was archived  # noqa: E501

        :return: The time_archived of this FileResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._time_archived

    @time_archived.setter
    def time_archived(self, time_archived):
        """Sets the time_archived of this FileResponse.

        The date & time this File was archived  # noqa: E501

        :param time_archived: The time_archived of this FileResponse.  # noqa: E501
        :type: datetime
        """

        self._time_archived = time_archived

    @property
    def storage_tier(self):
        """Gets the storage_tier of this FileResponse.  # noqa: E501


        :return: The storage_tier of this FileResponse.  # noqa: E501
        :rtype: StorageTier
        """
        return self._storage_tier

    @storage_tier.setter
    def storage_tier(self, storage_tier):
        """Sets the storage_tier of this FileResponse.


        :param storage_tier: The storage_tier of this FileResponse.  # noqa: E501
        :type: StorageTier
        """

        self._storage_tier = storage_tier

    @property
    def e_tag(self):
        """Gets the e_tag of this FileResponse.  # noqa: E501

        The File's ETag  # noqa: E501

        :return: The e_tag of this FileResponse.  # noqa: E501
        :rtype: str
        """
        return self._e_tag

    @e_tag.setter
    def e_tag(self, e_tag):
        """Sets the e_tag of this FileResponse.

        The File's ETag  # noqa: E501

        :param e_tag: The e_tag of this FileResponse.  # noqa: E501
        :type: str
        """

        self._e_tag = e_tag

    @property
    def format(self):
        """Gets the format of this FileResponse.  # noqa: E501

        The File's Format  # noqa: E501

        :return: The format of this FileResponse.  # noqa: E501
        :rtype: str
        """
        return self._format

    @format.setter
    def format(self, format):
        """Sets the format of this FileResponse.

        The File's Format  # noqa: E501

        :param format: The format of this FileResponse.  # noqa: E501
        :type: str
        """

        self._format = format

    @property
    def format_edam(self):
        """Gets the format_edam of this FileResponse.  # noqa: E501


        :return: The format_edam of this FileResponse.  # noqa: E501
        :rtype: str
        """
        return self._format_edam

    @format_edam.setter
    def format_edam(self, format_edam):
        """Sets the format_edam of this FileResponse.


        :param format_edam: The format_edam of this FileResponse.  # noqa: E501
        :type: str
        """

        self._format_edam = format_edam

    @property
    def status(self):
        """Gets the status of this FileResponse.  # noqa: E501


        :return: The status of this FileResponse.  # noqa: E501
        :rtype: FileStatus
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this FileResponse.


        :param status: The status of this FileResponse.  # noqa: E501
        :type: FileStatus
        """

        self._status = status

    @property
    def life_cycle(self):
        """Gets the life_cycle of this FileResponse.  # noqa: E501


        :return: The life_cycle of this FileResponse.  # noqa: E501
        :rtype: FileLifeCycleSettings
        """
        return self._life_cycle

    @life_cycle.setter
    def life_cycle(self, life_cycle):
        """Sets the life_cycle of this FileResponse.


        :param life_cycle: The life_cycle of this FileResponse.  # noqa: E501
        :type: FileLifeCycleSettings
        """

        self._life_cycle = life_cycle

    @property
    def restore_expiration(self):
        """Gets the restore_expiration of this FileResponse.  # noqa: E501

        Restore expiration time  # noqa: E501

        :return: The restore_expiration of this FileResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._restore_expiration

    @restore_expiration.setter
    def restore_expiration(self, restore_expiration):
        """Sets the restore_expiration of this FileResponse.

        Restore expiration time  # noqa: E501

        :param restore_expiration: The restore_expiration of this FileResponse.  # noqa: E501
        :type: datetime
        """

        self._restore_expiration = restore_expiration

    @property
    def presigned_url(self):
        """Gets the presigned_url of this FileResponse.  # noqa: E501

        The presigned Url allowing access to this File  # noqa: E501

        :return: The presigned_url of this FileResponse.  # noqa: E501
        :rtype: str
        """
        return self._presigned_url

    @presigned_url.setter
    def presigned_url(self, presigned_url):
        """Sets the presigned_url of this FileResponse.

        The presigned Url allowing access to this File  # noqa: E501

        :param presigned_url: The presigned_url of this FileResponse.  # noqa: E501
        :type: str
        """

        self._presigned_url = presigned_url

    @property
    def object_store_access(self):
        """Gets the object_store_access of this FileResponse.  # noqa: E501


        :return: The object_store_access of this FileResponse.  # noqa: E501
        :rtype: ObjectStoreAccess
        """
        return self._object_store_access

    @object_store_access.setter
    def object_store_access(self, object_store_access):
        """Sets the object_store_access of this FileResponse.


        :param object_store_access: The object_store_access of this FileResponse.  # noqa: E501
        :type: ObjectStoreAccess
        """

        self._object_store_access = object_store_access

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FileResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, FileResponse):
            return True

        return self.to_dict() != other.to_dict()




# flake8: noqa

# Import all APIs into this package.
# If you have many APIs here with many many models used in each API this may
# raise a `RecursionError`.
# In order to avoid this, import only the API that you directly need like:
#
#   from .api.analysis_storage_api import AnalysisStorageApi
#
# or import this package, but before doing it, use:
#
#   import sys
#   sys.setrecursionlimit(n)

# Import APIs into API package:
from libica.openapi.v2.api.analysis_storage_api import AnalysisStorageApi
from libica.openapi.v2.api.bundle_api import BundleApi
from libica.openapi.v2.api.bundle_data_api import BundleDataApi
from libica.openapi.v2.api.bundle_data_linking_batch_api import BundleDataLinkingBatchApi
from libica.openapi.v2.api.bundle_data_unlinking_batch_api import BundleDataUnlinkingBatchApi
from libica.openapi.v2.api.bundle_pipeline_api import BundlePipelineApi
from libica.openapi.v2.api.bundle_sample_api import BundleSampleApi
from libica.openapi.v2.api.bundle_tool_api import BundleToolApi
from libica.openapi.v2.api.connector_api import ConnectorApi
from libica.openapi.v2.api.data_api import DataApi
from libica.openapi.v2.api.data_format_api import DataFormatApi
from libica.openapi.v2.api.entitled_bundle_api import EntitledBundleApi
from libica.openapi.v2.api.entitlement_detail_api import EntitlementDetailApi
from libica.openapi.v2.api.event_code_api import EventCodeApi
from libica.openapi.v2.api.event_log_api import EventLogApi
from libica.openapi.v2.api.job_api import JobApi
from libica.openapi.v2.api.metadata_model_api import MetadataModelApi
from libica.openapi.v2.api.notification_channel_api import NotificationChannelApi
from libica.openapi.v2.api.pipeline_api import PipelineApi
from libica.openapi.v2.api.pipeline_language_api import PipelineLanguageApi
from libica.openapi.v2.api.project_api import ProjectApi
from libica.openapi.v2.api.project_analysis_api import ProjectAnalysisApi
from libica.openapi.v2.api.project_analysis_creation_batch_api import ProjectAnalysisCreationBatchApi
from libica.openapi.v2.api.project_base_api import ProjectBaseApi
from libica.openapi.v2.api.project_custom_events_api import ProjectCustomEventsApi
from libica.openapi.v2.api.project_custom_notification_subscriptions_api import ProjectCustomNotificationSubscriptionsApi
from libica.openapi.v2.api.project_data_api import ProjectDataApi
from libica.openapi.v2.api.project_data_copy_batch_api import ProjectDataCopyBatchApi
from libica.openapi.v2.api.project_data_linking_batch_api import ProjectDataLinkingBatchApi
from libica.openapi.v2.api.project_data_transfer_api import ProjectDataTransferApi
from libica.openapi.v2.api.project_data_unlinking_batch_api import ProjectDataUnlinkingBatchApi
from libica.openapi.v2.api.project_data_update_batch_api import ProjectDataUpdateBatchApi
from libica.openapi.v2.api.project_notification_subscriptions_api import ProjectNotificationSubscriptionsApi
from libica.openapi.v2.api.project_permission_api import ProjectPermissionApi
from libica.openapi.v2.api.project_pipeline_api import ProjectPipelineApi
from libica.openapi.v2.api.project_sample_api import ProjectSampleApi
from libica.openapi.v2.api.project_sample_batch_api import ProjectSampleBatchApi
from libica.openapi.v2.api.project_workflow_session_api import ProjectWorkflowSessionApi
from libica.openapi.v2.api.reference_set_api import ReferenceSetApi
from libica.openapi.v2.api.region_api import RegionApi
from libica.openapi.v2.api.sample_api import SampleApi
from libica.openapi.v2.api.sequencing_run_api import SequencingRunApi
from libica.openapi.v2.api.storage_bundle_api import StorageBundleApi
from libica.openapi.v2.api.storage_configuration_api import StorageConfigurationApi
from libica.openapi.v2.api.storage_credentials_api import StorageCredentialsApi
from libica.openapi.v2.api.system_api import SystemApi
from libica.openapi.v2.api.token_api import TokenApi
from libica.openapi.v2.api.user_api import UserApi
from libica.openapi.v2.api.workgroup_api import WorkgroupApi
